;; Generated package description from ebdb.el  -*- no-byte-compile: t -*-
(define-package "ebdb" "0.8.9.0.20220125.181918" "Contact management package" '((emacs "25.1") (seq "2.15")) :commit "c23b924374a46bfc40d61831438a9d72f1951857" :authors '(("Eric Abrahamsen" . "eric@ericabrahamsen.net")) :maintainer '("Eric Abrahamsen" . "eric@ericabrahamsen.net") :keywords '("convenience" "mail") :url "https://github.com/girzel/ebdb")
